# Features Contributions

## `SearchGooglePy` SuperClass:

<table>
    <tr>
        <th>Name</th>
        <th>Description</th>
    </tr>
    <tr>
        <td><a href="#searchgooglepy-superclass">SearchGooglePy</a></td>
        <td><p>The SuperClass that initialize the module.</p></td>
    </tr>
    <tr>
        <td><a href="#searchtext-funtion">search_text</a></td>
        <td><p>The `search_text` function is the function that is used to search on Google's (<tt>www.google.com</tt>) web-engine.</p></td>
    </tr>
    <tr>
        <td><a href="#searchimg-function">search_img</a></td>
        <td><p>The `search_img` function has the role to search images on Google's (<tt>www.google.com</tt>) web-engine.</p></td>
    </tr>
</table>

### `SearchGooglePy` superclass:

The SuperClass that initialize the module.

### `search_text` funtion:

The `search_text` function is the function that is used to search on Google's (`www.google.com`) web-engine.

@param `text` --- the text that you want to search on google.

### `search_img` function:

The `search_img` function has the role to search images on Google's (`www.google.com`) web-engine.

@param `text` --- The text that you want to search on google to display images.